@@ -22,7 +22,7 @@ function install_paswwd() {
         read -r -p "$( blue.sh "Enter internet/GitHub password: " )" INTERNET
       fi
     else
-      INTERNET="${PASSWORD}"
+      INTERNET="${2:-${PASSWORD}}"
     fi
     if echo "${PASSWORD}" | sudo -S true; then
       info.sh passwd "sudo password."
@@ -50,8 +50,8 @@ source "${PASSWD_PATH}" || exit 1
 sudoers.sh "$@" || exit 1
 essentials.sh "$@" || exit 1
 homefiles.sh || exit 1
-gconfig.sh || exit 1
 sshconfig.sh || exit 1
+gconfig.sh || exit 1
 
 ## BEGIN: SECRETS
 if test -f "${SECRETS_PATH}"; then
